@@ -6,7 +6,7 @@
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 #Contributions: Frank Visser - import, decrypt and encrypt from config file the user variables.
-#Version: 0.6-1
+Version = '0.6-3'
 
 import os
 import sys
@@ -142,6 +142,7 @@ ConfigVars = ['SENDERNUMBER',
                'COM_UNLOCK',
                'COM_TRACKON',
                'COM_TRACKOFF',
+               'COM_CUSTOM',
                'USER',         
                'PASSWORD',        
                'EMAILFROM',       
@@ -395,13 +396,14 @@ class MyMainWindow(QtGui.QMainWindow):
           self.ui.lineUnlock.setText(   "%s" % COM_UNLOCK)
           self.ui.lineTrackOn.setText(  "%s" % COM_TRACKON)
           self.ui.lineTrackOff.setText( "%s" % COM_TRACKOFF)
+          self.ui.lineScript.setText(   "%s" % COM_CUSTOM)
        
        def doAbout(self):
           msg = "The SMSCON Editor is a user interface to the configuration of the SMSCON.\n"
           msg += "It provides the ability to edit the options and name the secret pass-phrases of the commands used for controlling the device.\n"
           msg += "In addition, it provides an interface to initialise and configure the SMSCON daemon.\n"
           msg += "For more info see: http://wiki.maemo.org/SMSCON_Editor"
-          QMessageBox.about(self, "About - SMSCON Editor", msg)
+          QMessageBox.about(self, ("About - SMSCON Editor ver. %s " % Version ) , msg)
 
        def doCredits(self):
           msg = unichr(int('00A9', 16)) + "SMSCON - 2010, Frank Visser (digitalvoid)\n"
@@ -586,6 +588,7 @@ class MyMainWindow(QtGui.QMainWindow):
           self.ui.lineUnlock.setText(   "%s" % prefix + COM_UNLOCK)
           self.ui.lineTrackOn.setText(  "%s" % prefix + COM_TRACKON)
           self.ui.lineTrackOff.setText( "%s" % prefix + COM_TRACKOFF)
+          #self.ui.lineScript.setText(   "%s" % prefix + COM_CUSTOM)
 
        def doPrefix2(self):
           prefix = self.ui.linePrefix2.text()
@@ -602,6 +605,7 @@ class MyMainWindow(QtGui.QMainWindow):
           #self.ui.lineUnlock.setText(   "%s" % prefix + COM_UNLOCK)
           #self.ui.lineTrackOn.setText(  "%s" % prefix + COM_TRACKON)
           #self.ui.lineTrackOff.setText( "%s" % prefix + COM_TRACKOFF)
+          self.ui.lineScript.setText(   "%s" % prefix + COM_CUSTOM)
              
        def doCreateConfigCommands1(self):
 
@@ -654,7 +658,8 @@ class MyMainWindow(QtGui.QMainWindow):
           Power     = self.ui.linePower.text()
           Reboot    = self.ui.lineReboot.text()
           PowerOff  = self.ui.linePowerOff.text()
-
+          Script    = self.ui.lineScript.text()
+          
           #Update of the config file.
           os.rename( Path + ConfigFile, Path + ConfigFile + "~" )
           destination = open( Path + ConfigFile, "w" )
@@ -670,6 +675,8 @@ class MyMainWindow(QtGui.QMainWindow):
                 destination.write('COM_REBOOT        = \'%s\'\n' % Reboot)
              elif Line.startswith("COM_POWEROFF"):
                 destination.write('COM_POWEROFF      = \'%s\'\n' % PowerOff)
+             elif Line.startswith("COM_CUSTOM"):
+                destination.write('COM_CUSTOM        = \'%s\'\n' % Script)
              else: 
                 destination.write( Line )
           source.close()
